#
# spec file for package ghc-vector
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name vector
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.13.1.0
Release:        2.3
Summary:        Efficient Arrays
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-primitive-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-vector-stream-devel
BuildRequires:  ghc-vector-stream-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-base-orphans-devel
BuildRequires:  ghc-base-orphans-prof
BuildRequires:  ghc-doctest-devel
BuildRequires:  ghc-doctest-prof
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-random-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-inspection-testing-devel
BuildRequires:  ghc-tasty-inspection-testing-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
%endif

%description
An efficient implementation of 'Int'-indexed arrays (both mutable and
immutable), with a powerful loop optimisation framework .

It is structured as follows:

["Data.Vector"] Boxed vectors of arbitrary types.

["Data.Vector.Unboxed"] Unboxed vectors with an adaptive representation based
on data type families.

["Data.Vector.Storable"] Unboxed vectors of 'Storable' types.

["Data.Vector.Primitive"] Unboxed vectors of primitive types as defined by the
'primitive' package. "Data.Vector.Unboxed" is more flexible at no performance
cost.

["Data.Vector.Generic"] Generic interface to the vector types.

There is also a (draft) tutorial on common uses of vector.

* <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc README.md changelog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Mar 16 2024 Peter Simons <psimons@suse.com>
- Update vector to version 0.13.1.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Oct  7 2023 Peter Simons <psimons@suse.com>
- Update vector to version 0.13.1.0.
  [#] Changes in version 0.13.1.0
  * Specialized variants of `findIndexR` are reexported for all vector
    types. [#469](https://github.com/haskell/vector/pull/469)
  * `UnboxViaPrim` could be used for deriving `Unbox` instances (`V_UnboxViaPrim`
    constructor is exported) [#450](https://github.com/haskell/vector/pull/450)
  * Fields of `Data.Vector.Fusion.Bundle.Size` are now strict
    [#456](https://github.com/haskell/vector/pull/456)
  * Compatibility with future GHC 9.10 release
    [#462](https://github.com/haskell/vector/pull/462)
  * Test suite no longer fails when built with QuickCheck-2.14
    [#461](https://github.com/haskell/vector/pull/461)
  * Doctests now work with current versions of GHC
    [#465](https://github.com/haskell/vector/pull/466)
  * Various documentation improvements
* Thu Aug 10 2023 Peter Simons <psimons@suse.com>
- Update vector to version 0.13.0.0 revision 5.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Jul 27 2023 Peter Simons <psimons@suse.com>
- Update vector to version 0.13.0.0 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Feb 20 2023 Peter Simons <psimons@suse.com>
- Update vector to version 0.13.0.0 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Jan 16 2023 Peter Simons <psimons@suse.com>
- Update vector to version 0.13.0.0 revision 2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/vector-0.13.0.0/src/changelog.md
* Fri May 20 2022 Peter Simons <psimons@suse.com>
- Update vector to version 0.12.3.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Nov 16 2021 psimons@suse.com
- Update vector to version 0.12.3.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Sep 22 2021 psimons@suse.com
- Update vector to version 0.12.3.1.
  [#] Changes in version 0.12.3.1
  * Bugfix for ghcjs and `Double` memset for `Storable` vector:
    [#410](https://github.com/haskell/vector/issues/410)
  * Avoid haddock bug: [#383](https://github.com/haskell/vector/issues/383)
  * Improve haddock and doctests
  * Disable problematic tests with -boundschecks [#407](https://github.com/haskell/vector/pull/407)
* Tue Sep  7 2021 psimons@suse.com
- Update vector to version 0.12.3.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Apr  7 2021 psimons@suse.com
- Update vector to version 0.12.3.0.
  [#] Changes in version 0.12.3.0
  * Fix performance regression due to introduction of `keepAlive#` primop in ghc-9.0: [#372](https://github.com/haskell/vector/pull/372)
  * Add monadic functions for mutable vectors: [#338](https://github.com/haskell/vector/pull/338)
  * Added folds for monadic functions: `mapM_`, `imapM_`, `forM_`, `iforM_`,
    `foldl`, `foldl'`, `foldM`, `foldM'`, `ifoldl`, `ifoldl'`, `ifoldM`,
    `ifoldM'`
  * Added `modifyM` and `unsafeModifyM` for mutable vectors
  * Added `generate` and `generateM` for mutable vectors
* Fri Jan 29 2021 psimons@suse.com
- Update vector to version 0.12.2.0.
  [#] Changes in version 0.12.2.0
  * Add `MINIMAL` pragma to `Vector` & `MVector` type classes: [#11](https://github.com/haskell/vector/issues/11)
  * Export `unstreamM` from`from Data.Vector.Generic`: [#70](https://github.com/haskell/vector/issues/70)
  * New functions: `unfoldrExactN` and `unfoldrExactNM`: [#140](https://github.com/haskell/vector/issues/140)
  * Added `iforM` and `iforM_`: [#262](https://github.com/haskell/vector/issues/262)
  * Added `MonadFix` instance for boxed vectors: [#178](https://github.com/haskell/vector/issues/178)
  * Added `uncons` and `unsnoc`: [#212](https://github.com/haskell/vector/issues/212)
  * Added `foldMap` and `foldMap'`: [#263](https://github.com/haskell/vector/issues/263)
  * Added `isSameVector` for storable vectors
  * Added `toArray`, `fromArray`, `toMutableArray` and `fromMutableArray`
  * Added `iscanl`, `iscanl'`, `iscanr`, `iscanr'` to `Primitive`, `Storable` and `Unboxed`
  * Added `izipWithM`, `izipWithM_`, `imapM` and `imapM_` to `Primitive` and `Storable`
  * Added `ifoldM`, `ifoldM'`, `ifoldM_` and `ifoldM'_` to `Primitive` and `Storable`
  * Added `eqBy` and `cmpBy`
  * Added `findIndexR` to `Generic`: [#172](https://github.com/haskell/vector/issues/172)
  * Added `catMaybes`: [#329](https://github.com/haskell/vector/issues/329)
  * Added `mapMaybeM` and `imapMaybeM`: [#183](https://github.com/haskell/vector/issues/183)
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Feb  7 2020 psimons@suse.com
- Update vector to version 0.12.1.2.
  Upstream has renamed and modified the change log file(s) in this
  release. Unfortunately, the automatic updater cannot reliable
  determine relevant entries for this release.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Wed May  1 2019 psimons@suse.com
- Update vector to version 0.12.0.3.
  Changes in version 0.12.0.3
  * Add support for ghc >=8.8 monad fail
* Sat Dec  8 2018 psimons@suse.com
- Update vector to version 0.12.0.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/vector-0.12.0.2/src/changelog
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Wed Jul 18 2018 psimons@suse.com
- Revise cabal build file to specify more accurate dependencies.
* Wed May 16 2018 psimons@suse.com
- Prefer the new %%license attribute over %%doc.
- Update Cabal file to revision 2.
  * add support for GHC 8.4.x
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.12.0.1 revision 1.
* Mon Nov 21 2016 psimons@suse.com
- Update to version 0.11.0.0 revision 2 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.11.0.0 revision 1 with cabal2obs.
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 0.11.0.0
  * Define `Applicative` instances for `Data.Vector.Fusion.Util.{Box,Id}`
  * Define non-bottom `fail` for `instance Monad Vector`
  * New generalized stream fusion framework
  * Various safety fixes
  - Various overflows due to vector size have been eliminated
  - Memory is initialized on creation of unboxed vectors
  * Changes to SPEC usage to allow building under more conditions
* Tue Apr 14 2015 mimi.vx@gmail.com
- update to 0.10.12.3
  * Allow building with `primtive-0.6`
  * Add support for `deepseq-1.4.0.0`
  * Fixed compilation on non-head GHCs
  * Export MVector constructor from Data.Vector.Primitive to match Vector's
  (which was already exported).
  * Fix building on GHC 7.9 by adding Applicative instances for Id and Box
  * Support OverloadedLists for boxed Vector in GHC >= 7.8
  * Add support for OverloadedLists in GHC >= 7.8
  * Fix compilation with GHC 7.9
* Sat Oct 18 2014 peter.trommler@ohm-hochschule.de
- update to 0.10.9.1
  * no changelog
  * Haskell Platform 2014.2.0.0
- regenerate spec file
- drop vector-debian-no_ann_without_ghci.patch
  * we have ghci for all platforms now
* Sat Oct 18 2014 dvaleev@suse.com
- Fix PowerPC 64bit builds (vector-debian-no_ann_without_ghci.patch)
  https://ghc.haskell.org/trac/ghc/ticket/4268
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- BR ghc-deepseq-devel explicitly rather that relying on Cabal
  to pull it in
- more transparent packaging (fewer macros)
* Mon Jan  7 2013 peter.trommler@ohm-hochschule.de
- expand macro in name tag to help source validator
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service loaclonly for Factory submission
* Wed Oct 17 2012 peter.trommler@ohm-hochschule.de
- update to 0.10.0.1 from upstream (HP 2012.4.0.0 RC2)
* Tue Oct  2 2012 peter.trommler@ohm-hochschule.de
- update to 0.10 from upstream
- required by Haskell Platform 2012.4.0.0
* Thu May 17 2012 peter.trommler@ohm-hochschule.de
- spec file template generated by cabal2spec-0.25.5
* Wed Jan 18 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
